/************************************************************************************
gpsserviceirs
Copyright (c) 2010, International Rescue System Institute
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD license.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

//***********************************************************************************************//
//* GpsService.cpp								     2009.10.30 *//
//*												*//
//* GPS Service RTMプログラム [Ver.1.0.0]							*//
//*												*//
//* GPSセンサモジュール TOPCON LEGACY-E+ シリアル設定						*//
//*	通信方式	: 歩調同期方式(非同期)		[固定]					*//
//*	通信速度	: 115200 [bps]								*//
//*	データ長	: 8 [bit]			[固定]					*//
//*	パリティビット	: なし				[固定]					*//
//*	ストップビット	: 1 [bit]								*//
//*	フロー制御	: ハードウェアハンドシェイク						*//
//*												*//
//* コンフィギュレーション									*//
//*	01_modemdevice	: COMアドレス								*//
//*			  [/dev/ttyS0, /dev/ttyS1, /dev/ttyS2, /dev/ttyS3, /dev/ttyS4]		*//
//*	02_baundrate	: ボーレート [bps]							*//
//*			  [300, 600, 1200, 2400, 4800, 9600, 19200, 38400, 57600,		*//
//*				115200, 230400, 460800]						*//
//*			  [注意] 153600 -> g++が未対応につき使用不可				*//
//*			  [参照] /usr/include/bits/termios.h					*//
//*	03_stopbit	: ストップビット [bit]							*//
//*			  [1, 2]								*//
//*	04_rtscts	: ハードウェアハンドシェイク						*//
//*			  [off, on]								*//
//*	05_serialport	: シリアルポート							*//
//*			  [/dev/ser/a, /dev/ser/b, /dev/ser/c]					*//
//*	06_sendtime	: 測位更新間隔 [s]							*//
//*			  [0.1, 0.2, 0.3, 0.4, 0.5, 0.6. 0.7, 0.8, 0.9, 1.0]			*//
//*	07_gga		: GGAメッセージ								*//
//*			  [off, on]								*//
//*	08_gll		: GLLメッセージ								*//
//*			  [off, on]								*//
//*	09_gns		: GNSメッセージ								*//
//*			  [off, on]								*//
//*	10_grs		: GRSメッセージ								*//
//*			  [off, on]								*//
//*	11_gsa		: GSAメッセージ								*//
//*			  [off, on]								*//
//*	12_gst		: GSTメッセージ								*//
//*			  [off, on]								*//
//*	13_gsv		: GSVメッセージ								*//
//*			  [off, on]								*//
//*	14_hdt		: HDTメッセージ								*//
//*			  [off, on]								*//
//*	15_rmc		: RMCメッセージ								*//
//*			  [off, on]								*//
//*	16_vtg		: VTGメッセージ								*//
//*			  [off, on]								*//
//*	17_zda		: ZDAメッセージ								*//
//*			  [off, on]								*//
//***********************************************************************************************//


// -*- C++ -*-
/*!
 * @file  GpsService.cpp
 * @brief Service for LEGACY-E+
 * $Date$
 *
 * $Id$
 */

#include "GpsService.h"


//-- [変数宣言] --------------------------------------------------------------------------------//
int wait_flag = 1;											// フラグ格納変数 [読み取り用]
//----------------------------------------------------------------------------------------------//


// Module specification
// <rtc-template block="module_spec">
static const char* gpsservice_spec[] =
  {
    "implementation_id", "GpsService",
    "type_name",         "GpsService",
    "description",       "Service for LEGACY-E+",
    "version",           "1.0.0",
    "vendor",            "IRS",
    "category",          "Device",
    "activity_type",     "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.01_modemdevice", "/dev/ttyS0",
    "conf.default.02_baudrate", "115200",
    "conf.default.03_stopbit", "1",
    "conf.default.04_rtscts", "on",
    "conf.default.05_serialport", "/dev/ser/b",
    "conf.default.06_sendtime", "0.1",
    "conf.default.07_gga", "on",
    "conf.default.08_gll", "on",
    "conf.default.09_gns", "on",
    "conf.default.10_grs", "on",
    "conf.default.11_gsa", "on",
    "conf.default.12_gst", "on",
    "conf.default.13_gsv", "on",
    "conf.default.14_hdt", "on",
    "conf.default.15_rmc", "on",
    "conf.default.16_vtg", "on",
    "conf.default.17_zda", "on",

    ""
  };
// </rtc-template>

GpsService::GpsService(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    // <rtc-template block="initializer">
    m_LegacyDataOut("LegacyData", m_LegacyData),
    
    // </rtc-template>
	dummy(0)
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  registerOutPort("LegacyData", m_LegacyDataOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

}

GpsService::~GpsService()
{
}

RTC::ReturnCode_t GpsService::onInitialize()
{
	// <rtc-template block="bind_config">
	// Bind variables and configuration variable
	bindParameter("01_modemdevice", m_01_modemdevice, "/dev/ttyS0");
	bindParameter("02_baudrate", m_02_baudrate, "115200");
	bindParameter("03_stopbit", m_03_stopbit, "1");
	bindParameter("04_rtscts", m_04_rtscts, "on");
	bindParameter("05_serialport", m_05_serialport, "/dev/ser/b");
	bindParameter("06_sendtime", m_06_sendtime, "0.1");
	bindParameter("07_gga", m_07_gga, "on");
	bindParameter("08_gll", m_08_gll, "on");
	bindParameter("09_gns", m_09_gns, "on");
	bindParameter("10_grs", m_10_grs, "on");
	bindParameter("11_gsa", m_11_gsa, "on");
	bindParameter("12_gst", m_12_gst, "on");
	bindParameter("13_gsv", m_13_gsv, "on");
	bindParameter("14_hdt", m_14_hdt, "on");
	bindParameter("15_rmc", m_15_rmc, "on");
	bindParameter("16_vtg", m_16_vtg, "on");
	bindParameter("17_zda", m_17_zda, "on");

	// </rtc-template>


	//-- [初期化] --------------------------------------------------------------------------//

	// GGAメッセージ初期化
	m_LegacyData.gga.field00.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field01.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field02.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field03.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field04.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field05.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field06.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field07.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field08.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field09.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field10.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field11.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field12.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field13.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field14.length(DATASIZE);							// メモリ確保 [GGA]
	m_LegacyData.gga.field15.length(DATASIZE);							// メモリ確保 [GGA]

	// GLLメッセージ初期化
	m_LegacyData.gll.field00.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field01.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field02.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field03.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field04.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field05.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field06.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field07.length(DATASIZE);							// メモリ確保 [GLL]
	m_LegacyData.gll.field08.length(DATASIZE);							// メモリ確保 [GLL]

	// GNSメッセージ初期化
	m_LegacyData.gns.field00.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field01.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field02.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field03.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field04.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field05.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field06.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field07.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field08.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field09.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field10.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field11.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.field12.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gp_field00.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gp_field01.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gp_field07.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gp_field11.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gp_field12.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gl_field00.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gl_field01.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gl_field07.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gl_field11.length(DATASIZE);							// メモリ確保 [GNS]
	m_LegacyData.gns.gl_field12.length(DATASIZE);							// メモリ確保 [GNS]

	// GRSメッセージ初期化
	m_LegacyData.grs.gp_field00.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field01.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field02.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_01.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_02.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_03.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_04.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_05.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_06.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_07.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_08.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_09.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_10.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_11.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field03_12.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gp_field04.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field00.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field01.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field02.length(DATASIZE);							// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_01.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_02.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_03.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_04.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_05.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_06.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_07.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_08.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_09.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_10.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_11.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field03_12.length(DATASIZE);						// メモリ確保 [GRS]
	m_LegacyData.grs.gl_field04.length(DATASIZE);							// メモリ確保 [GRS]

	// GSAメッセージ初期化
	m_LegacyData.gsa.gp_field00.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field01.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field02.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_01.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_02.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_03.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_04.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_05.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_06.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_07.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_08.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_09.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_10.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_11.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field03_12.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field04.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field05.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field06.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gp_field07.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field00.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field01.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field02.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_01.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_02.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_03.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_04.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_05.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_06.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_07.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_08.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_09.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_10.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_11.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field03_12.length(DATASIZE);						// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field04.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field05.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field06.length(DATASIZE);							// メモリ確保 [GSA]
	m_LegacyData.gsa.gl_field07.length(DATASIZE);							// メモリ確保 [GSA]

	// GSTメッセージ初期化
	m_LegacyData.gst.field00.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field01.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field02.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field03.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field04.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field05.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field06.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field07.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field08.length(DATASIZE);							// メモリ確保 [GST]
	m_LegacyData.gst.field09.length(DATASIZE);							// メモリ確保 [GST]

	// GSVメッセージ初期化
	m_LegacyData.gsv.gp1_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp1_field05.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp2_field05.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gp3_field05.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl1_field05.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl2_field05.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field00.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field01.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field02.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field03.length(DATASIZE);							// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_1_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_1_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_1_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_1_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_2_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_2_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_2_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_2_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_3_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_3_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_3_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_3_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_4_1.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_4_2.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_4_3.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field04_4_4.length(DATASIZE);						// メモリ確保 [GSV]
	m_LegacyData.gsv.gl3_field05.length(DATASIZE);							// メモリ確保 [GSV]

	// HDTメッセージ初期化
	m_LegacyData.hdt.field00.length(DATASIZE);							// メモリ確保 [HDT]
	m_LegacyData.hdt.field01.length(DATASIZE);							// メモリ確保 [HDT]
	m_LegacyData.hdt.field02.length(DATASIZE);							// メモリ確保 [HDT]
	m_LegacyData.hdt.field03.length(DATASIZE);							// メモリ確保 [HDT]

	// RMCメッセージ初期化
	m_LegacyData.rmc.field00.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field01.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field02.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field03.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field04.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field05.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field06.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field07.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field08.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field09.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field10.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field11.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field12.length(DATASIZE);							// メモリ確保 [RMC]
	m_LegacyData.rmc.field13.length(DATASIZE);							// メモリ確保 [RMC]

	// VTGメッセージ初期化
	m_LegacyData.vtg.field00.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field01.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field02.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field03.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field04.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field05.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field06.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field07.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field08.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field09.length(DATASIZE);							// メモリ確保 [VTG]
	m_LegacyData.vtg.field10.length(DATASIZE);							// メモリ確保 [VTG]

	// ZDAメッセージ初期化
	m_LegacyData.zda.field00.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field01.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field02.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field03.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field04.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field05.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field06.length(DATASIZE);							// メモリ確保 [ZDA]
	m_LegacyData.zda.field07.length(DATASIZE);							// メモリ確保 [ZDA]

	//--------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

/*
RTC::ReturnCode_t GpsService::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t GpsService::onActivated(RTC::UniqueId ec_id)
{


	//-- [初期化] --------------------------------------------------------------------------//

	wait_flag = 1;											// フラグ初期化 [読み取り用]
	check     = 0;											// チェック初期化
	checksum  = 0;											// チェックサム初期化
	strcpy(checkbuf, "");										// チェックサムバッファ初期化
	err_flag  = 0;											// エラーフラグ初期化
	num_cflag = 0;											// cflag用引数初期化
	message   = 0;											// メッセージモード初期化
	now_time  = gettimeofday_sec();									// 現在時刻初期化
	timeout   = 0.0;										// タイムアウト初期化
	sec       = 0;											// タイムスタンプ初期化 [sec]
	nsec      = 0;											// タイムスタンプ初期化 [nsec]
	for(i = 0; i < 11; i++) check_flag[i] = 0;							// チェックサムフラグ初期化

	//--------------------------------------------------------------------------------------//


	//-- [メッセージ初期化] ----------------------------------------------------------------//

	for(i = 0; i < 16; i++) strcpy(gga[i], "");							// 初期化 [GGA]
	for(i = 0; i <  9; i++) strcpy(gll[i], "");							// 初期化 [GLL]
	for(i = 0; i < 13; i++) strcpy(gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 13; i++) strcpy(gp_gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 13; i++) strcpy(gl_gns[i], "");							// 初期化 [GNS]
	for(i = 0; i < 16; i++) strcpy(gp_grs[i], "");							// 初期化 [GRS]
	for(i = 0; i < 16; i++) strcpy(gl_grs[i], "");							// 初期化 [GRS]
	for(i = 0; i < 19; i++) strcpy(gp_gsa[i], "");							// 初期化 [GSA]
	for(i = 0; i < 19; i++) strcpy(gl_gsa[i], "");							// 初期化 [GSA]
	for(i = 0; i < 10; i++) strcpy(gst[i], "");							// 初期化 [GST]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[0][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[1][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gp_gsv[2][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[0][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[1][i], "");						// 初期化 [GSV]
	for(i = 0; i < 21; i++) strcpy(gl_gsv[2][i], "");						// 初期化 [GSV]
	for(i = 0; i <  4; i++) strcpy(hdt[i], "");							// 初期化 [HDT]
	for(i = 0; i < 14; i++) strcpy(rmc[i], "");							// 初期化 [RMC]
	for(i = 0; i < 11; i++) strcpy(vtg[i], "");							// 初期化 [VTG]
	for(i = 0; i <  8; i++) strcpy(zda[i], "");							// 初期化 [ZDA]

	//--------------------------------------------------------------------------------------//


	//-- [出力ポート初期化] ----------------------------------------------------------------//

	// タイムスタンプ初期化
	m_LegacyData.tm.sec  = 0;									// 初期化 [tm]
	m_LegacyData.tm.nsec = 0;									// 初期化 [tm]

	// モード初期化
	m_LegacyData.mode = 0;										// 初期化 [mode]

	// GGAメッセージ初期化
	m_LegacyData.gga.field00[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field01[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field02[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field03[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field04[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field05[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field06[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field07[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field08[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field09[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field10[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field11[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field12[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field13[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field14[0] = 0x00;								// 初期化 [GGA]
	m_LegacyData.gga.field15[0] = 0x00;								// 初期化 [GGA]

	// GLLメッセージ初期化
	m_LegacyData.gll.field00[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field01[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field02[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field03[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field04[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field05[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field06[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field07[0] = 0x00;								// 初期化 [GLL]
	m_LegacyData.gll.field08[0] = 0x00;								// 初期化 [GLL]

	// GNSメッセージ初期化
	m_LegacyData.gns.field00[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field01[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field02[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field03[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field04[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field05[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field06[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field07[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field08[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field09[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field10[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field11[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.field12[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gp_field00[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gp_field01[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gp_field07[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gp_field11[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gp_field12[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gl_field00[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gl_field01[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gl_field07[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gl_field11[0] = 0x00;								// 初期化 [GNS]
	m_LegacyData.gns.gl_field12[0] = 0x00;								// 初期化 [GNS]

	// GRSメッセージ初期化
	m_LegacyData.grs.gp_field00[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gp_field01[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gp_field02[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_01[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_02[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_03[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_04[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_05[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_06[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_07[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_08[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_09[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_10[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_11[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field03_12[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gp_field04[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gl_field00[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gl_field01[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gl_field02[0] = 0x00;								// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_01[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_02[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_03[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_04[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_05[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_06[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_07[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_08[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_09[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_10[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_11[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field03_12[0] = 0x00;							// 初期化 [GRS]
	m_LegacyData.grs.gl_field04[0] = 0x00;								// 初期化 [GRS]

	// GSAメッセージ初期化
	m_LegacyData.gsa.gp_field00[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field01[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field02[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_01[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_02[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_03[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_04[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_05[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_06[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_07[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_08[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_09[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_10[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_11[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field03_12[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gp_field04[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field05[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field06[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gp_field07[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field00[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field01[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field02[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_01[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_02[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_03[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_04[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_05[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_06[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_07[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_08[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_09[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_10[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_11[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field03_12[0] = 0x00;							// 初期化 [GSA]
	m_LegacyData.gsa.gl_field04[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field05[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field06[0] = 0x00;								// 初期化 [GSA]
	m_LegacyData.gsa.gl_field07[0] = 0x00;								// 初期化 [GSA]

	// GSTメッセージ初期化
	m_LegacyData.gst.field00[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field01[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field02[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field03[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field04[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field05[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field06[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field07[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field08[0] = 0x00;								// 初期化 [GST]
	m_LegacyData.gst.field09[0] = 0x00;								// 初期化 [GST]

	// GSVメッセージ初期化
	m_LegacyData.gsv.gp1_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp1_field05[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp2_field05[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gp3_field05[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl1_field05[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl2_field05[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field00[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field01[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field02[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field03[0] = 0x00;								// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_1_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_1_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_1_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_1_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_2_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_2_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_2_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_2_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_3_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_3_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_3_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_3_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_4_1[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_4_2[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_4_3[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field04_4_4[0] = 0x00;							// 初期化 [GSV]
	m_LegacyData.gsv.gl3_field05[0] = 0x00;								// 初期化 [GSV]

	// HDTメッセージ初期化
	m_LegacyData.hdt.field00[0] = 0x00;								// 初期化 [HDT]
	m_LegacyData.hdt.field01[0] = 0x00;								// 初期化 [HDT]
	m_LegacyData.hdt.field02[0] = 0x00;								// 初期化 [HDT]
	m_LegacyData.hdt.field03[0] = 0x00;								// 初期化 [HDT]

	// RMCメッセージ初期化
	m_LegacyData.rmc.field00[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field01[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field02[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field03[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field04[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field05[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field06[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field07[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field08[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field09[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field10[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field11[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field12[0] = 0x00;								// 初期化 [RMC]
	m_LegacyData.rmc.field13[0] = 0x00;								// 初期化 [RMC]

	// VTGメッセージ初期化
	m_LegacyData.vtg.field00[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field01[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field02[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field03[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field04[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field05[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field06[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field07[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field08[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field09[0] = 0x00;								// 初期化 [VTG]
	m_LegacyData.vtg.field10[0] = 0x00;								// 初期化 [VTG]

	// ZDAメッセージ初期化
	m_LegacyData.zda.field00[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field01[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field02[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field03[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field04[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field05[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field06[0] = 0x00;								// 初期化 [ZDA]
	m_LegacyData.zda.field07[0] = 0x00;								// 初期化 [ZDA]

	//--------------------------------------------------------------------------------------//


	//-- [コンフィギュレーション読み込み] --------------------------------------------------//

	strcpy(modemdevice, m_01_modemdevice.c_str());							// データ格納 [COMアドレス]
	strcpy(baudrate,    m_02_baudrate.c_str());							// データ格納 [ボーレート]
	strcpy(stopbit,     m_03_stopbit.c_str());							// データ格納 [ストップビット]
	strcpy(rtscts,      m_04_rtscts.c_str());							// データ格納 [ハードシェイク]
	strcpy(serialport,  m_05_serialport.c_str());							// データ格納 [シリアルポート]
	strcpy(sendtime,    m_06_sendtime.c_str());							// データ格納 [測位更新間隔]
	strcpy(mes_gga,     m_07_gga.c_str());								// データ格納 [モード:GGA]
	strcpy(mes_gll,     m_08_gll.c_str());								// データ格納 [モード:GLL]
	strcpy(mes_gns,     m_09_gns.c_str());								// データ格納 [モード:GNS]
	strcpy(mes_grs,     m_10_grs.c_str());								// データ格納 [モード:GRS]
	strcpy(mes_gsa,     m_11_gsa.c_str());								// データ格納 [モード:GSA]
	strcpy(mes_gst,     m_12_gst.c_str());								// データ格納 [モード:GST]
	strcpy(mes_gsv,     m_13_gsv.c_str());								// データ格納 [モード:GSV]
	strcpy(mes_hdt,     m_14_hdt.c_str());								// データ格納 [モード:HDT]
	strcpy(mes_rmc,     m_15_rmc.c_str());								// データ格納 [モード:RMC]
	strcpy(mes_vtg,     m_16_vtg.c_str());								// データ格納 [モード:VTG]
	strcpy(mes_zda,     m_17_zda.c_str());								// データ格納 [モード:ZDA]

	//--------------------------------------------------------------------------------------//


	//-- [デバッグconfiguration] -----------------------------------------------------------//

	#ifndef DEBUG_CONFIGURATION									// デバッグ表示開始

	printf("\n[configuration]\n");									// label
	printf("01_modemdevice = %s\n", modemdevice);							// modemdevice
	printf("02_baudrate    = %s\n", baudrate);							// baudrate
	printf("03_stopbit     = %s\n", stopbit);							// stopbit
	printf("04_rtscts      = %s\n", rtscts);							// rtscts
	printf("05_serialport  = %s\n", serialport);							// serialport
	printf("06_sendtime    = %s\n", sendtime);							// sendtime
	printf("07_gga         = %s\n", mes_gga);							// mes_gga
	printf("08_gll         = %s\n", mes_gll);							// mes_gll
	printf("09_gns         = %s\n", mes_gns);							// mes_gns
	printf("10_grs         = %s\n", mes_grs);							// mes_grs
	printf("11_gsa         = %s\n", mes_gsa);							// mes_gsa
	printf("12_gst         = %s\n", mes_gst);							// mes_gst
	printf("13_gsv         = %s\n", mes_gsv);							// mes_gsv
	printf("14_hdt         = %s\n", mes_hdt);							// mes_hdt
	printf("15_rmc         = %s\n", mes_rmc);							// mes_rmc
	printf("16_vtg         = %s\n", mes_vtg);							// mes_vtg
	printf("17_zda         = %s\n\n", mes_zda);							// mes_zda
	fflush(stdout);											// バッファフラッシュ [printf表示用]

	#endif												// デバッグ表示終了

	//--------------------------------------------------------------------------------------//


	//-- [コンフィギュレーションチェック] --------------------------------------------------//

	// COMアドレスチェック
	if(strcmp("/dev/ttyS0", modemdevice) == 0);							// COMアドレスチェック [COM1]
	else if(strcmp("/dev/ttyS1", modemdevice) == 0);						// COMアドレスチェック [COM2]
	else if(strcmp("/dev/ttyS2", modemdevice) == 0);						// COMアドレスチェック [COM3]
	else if(strcmp("/dev/ttyS3", modemdevice) == 0);						// COMアドレスチェック [COM4]
	else if(strcmp("/dev/ttyS4", modemdevice) == 0);						// COMアドレスチェック [COM5]
	else if(strcmp("/dev/ttyUSB0", modemdevice) == 0);						// COMアドレスチェック [COM1]
	else if(strcmp("/dev/ttyUSB1", modemdevice) == 0);						// COMアドレスチェック [COM2]
	else if(strcmp("/dev/ttyUSB2", modemdevice) == 0);						// COMアドレスチェック [COM3]
	else if(strcmp("/dev/ttyUSB3", modemdevice) == 0);						// COMアドレスチェック [COM4]
	else if(strcmp("/dev/ttyUSB4", modemdevice) == 0);						// COMアドレスチェック [COM5]
	else{												// 入力エラー [COMアドレス]

		printf("configuration error:01_modemdevice = %s\n", modemdevice);			// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// ボーレートチェック
	if(strcmp("300", baudrate) == 0) num_cflag = num_cflag | B300;					// ボーレート設定 [B300]
	else if(strcmp("600",    baudrate) == 0) num_cflag = num_cflag | B600;				// ボーレート設定 [B600]
	else if(strcmp("1200",   baudrate) == 0) num_cflag = num_cflag | B1200;				// ボーレート設定 [B1200]
	else if(strcmp("2400",   baudrate) == 0) num_cflag = num_cflag | B2400;				// ボーレート設定 [B2400]
	else if(strcmp("4800",   baudrate) == 0) num_cflag = num_cflag | B4800;				// ボーレート設定 [B4800]
	else if(strcmp("9600",   baudrate) == 0) num_cflag = num_cflag | B9600;				// ボーレート設定 [B9600]
	else if(strcmp("19200",  baudrate) == 0) num_cflag = num_cflag | B19200;			// ボーレート設定 [B19200]
	else if(strcmp("38400",  baudrate) == 0) num_cflag = num_cflag | B38400;			// ボーレート設定 [B38400]
	else if(strcmp("57600",  baudrate) == 0) num_cflag = num_cflag | B57600;			// ボーレート設定 [B57600]
	else if(strcmp("115200", baudrate) == 0) num_cflag = num_cflag | B115200;			// ボーレート設定 [B115200]
	else if(strcmp("230400", baudrate) == 0) num_cflag = num_cflag | B230400;			// ボーレート設定 [B230400]
	else if(strcmp("460800", baudrate) == 0) num_cflag = num_cflag | B460800;			// ボーレート設定 [B460800]
	else{												// 入力エラー [ボーレート]

		printf("configuration error:02_baudrate = %s\n", baudrate);				// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// ストップビットチェック
	if(strcmp("1", stopbit) == 0) num_cflag = num_cflag | 0;					// ストップビット設定 [1]
	else if(strcmp("2", stopbit) == 0) num_cflag = num_cflag | CSTOPB;				// ストップビット設定 [2]
	else{												// 入力エラー [ストップビット]

		printf("configuration error:03_stopbit = %s\n", stopbit);				// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// ハードシェイクチェック
	if(strcmp("off", rtscts) == 0) num_cflag = num_cflag | 0;					// ハードシェイク設定 [0]
	else if(strcmp("on", rtscts) == 0) num_cflag = num_cflag | CRTSCTS;				// ハードシィイク設定 [CRTSCTS]
	else{												// 入力エラー [ハードシェイク]

		printf("configuration error:04_rtscts = %s\n", rtscts);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// シリアルポートチェック
	if(strcmp("/dev/ser/a", serialport) == 0);							// シリアルポートチェック [COMA]
	else if(strcmp("/dev/ser/b", serialport) == 0);							// シリアルポートチェック [COMB]
	else if(strcmp("/dev/ser/c", serialport) == 0);							// シリアルポートチェック [COMC]
	else{												// 入力エラー [シリアルポート]

		printf("configuration error:05_serialport = %s\n", serialport);				// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// 測位更新間隔チェック
	if(strcmp("0.1", sendtime) == 0)      timeout = 0.1 * COEFFICIENT;				// 測位更新間隔チェック [0.1]
	else if(strcmp("0.2", sendtime) == 0) timeout = 0.2 * COEFFICIENT;				// 測位更新間隔チェック [0.2]
	else if(strcmp("0.3", sendtime) == 0) timeout = 0.3 * COEFFICIENT;				// 測位更新間隔チェック [0.3]
	else if(strcmp("0.4", sendtime) == 0) timeout = 0.4 * COEFFICIENT;				// 測位更新間隔チェック [0.4]
	else if(strcmp("0.5", sendtime) == 0) timeout = 0.5 * COEFFICIENT;				// 測位更新間隔チェック [0.5]
	else if(strcmp("0.6", sendtime) == 0) timeout = 0.6 * COEFFICIENT;				// 測位更新間隔チェック [0.6]
	else if(strcmp("0.7", sendtime) == 0) timeout = 0.7 * COEFFICIENT;				// 測位更新間隔チェック [0.7]
	else if(strcmp("0.8", sendtime) == 0) timeout = 0.8 * COEFFICIENT;				// 測位更新間隔チェック [0.8]
	else if(strcmp("0.9", sendtime) == 0) timeout = 0.9 * COEFFICIENT;				// 測位更新間隔チェック [0.9]
	else if(strcmp("1.0", sendtime) == 0) timeout = 1.0 * COEFFICIENT;				// 測位更新間隔チェック [1.0]
	else{												// 入力エラー [測位更新間隔]

		printf("configuration error:06_sendtime = %s\n", sendtime);				// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GGAメッセージチェック
	if(strcmp("off", mes_gga) == 0) message = message;						// GGAメッセージ設定 [未受信]
	else if(strcmp("on", mes_gga) == 0) message = message + 0x0001;					// GGAメッセージ設定 [受信]
	else{												// 入力エラー [GGAメッセージ]

		printf("configuration error:07_gga = %s\n", mes_gga);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GLLメッセージチェック
	if(strcmp("off", mes_gll) == 0) message = message;						// GLLメッセージ設定 [未受信]
	else if(strcmp("on", mes_gll) == 0) message = message + 0x0002;					// GLLメッセージ設定 [受信]
	else{												// 入力エラー [GLLメッセージ]

		printf("configuration error:08_gll = %s\n", mes_gll);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GNSメッセージチェック
	if(strcmp("off", mes_gns) == 0) message = message;						// GNSメッセージ設定 [未受信]
	else if(strcmp("on", mes_gns) == 0) message = message + 0x0004;					// GNSメッセージ設定 [受信]
	else{												// 入力エラー [GNSメッセージ]

		printf("configuration error:09_gns = %s\n", mes_gns);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GRSメッセージチェック
	if(strcmp("off", mes_grs) == 0) message = message;						// GRSメッセージ設定 [未受信]
	else if(strcmp("on", mes_grs) == 0) message = message + 0x0008;					// GRSメッセージ設定 [受信]
	else{												// 入力エラー [GRSメッセージ]

		printf("configuration error:10_grs = %s\n", mes_grs);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GSAメッセージチェック
	if(strcmp("off", mes_gsa) == 0) message = message;						// GSAメッセージ設定 [未受信]
	else if(strcmp("on", mes_gsa) == 0) message = message + 0x0010;					// GSAメッセージ設定 [受信]
	else{												// 入力エラー [GSAメッセージ]

		printf("configuration error:11_gsa = %s\n", mes_gsa);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GSTメッセージチェック
	if(strcmp("off", mes_gst) == 0) message = message;						// GSTメッセージ設定 [未受信]
	else if(strcmp("on", mes_gst) == 0) message = message + 0x0020;					// GSTメッセージ設定 [受信]
	else{												// 入力エラー [GSTメッセージ]

		printf("configuration error:12_gst = %s\n", mes_gst);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// GSVメッセージチェック
	if(strcmp("off", mes_gsv) == 0) message = message;						// GSVメッセージ設定 [未受信]
	else if(strcmp("on", mes_gsv) == 0) message = message + 0x0040;					// GSVメッセージ設定 [受信]
	else{												// 入力エラー [GSVメッセージ]

		printf("configuration error:13_gsv = %s\n", mes_gsv);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// HDTメッセージチェック
	if(strcmp("off", mes_hdt) == 0) message = message;						// HDTメッセージ設定 [未受信]
	else if(strcmp("on", mes_hdt) == 0) message = message + 0x0080;					// HDTメッセージ設定 [受信]
	else{												// 入力エラー [HDTメッセージ]

		printf("configuration error:14_hdt = %s\n", mes_hdt);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// RMCメッセージチェック
	if(strcmp("off", mes_rmc) == 0) message = message;						// RMCメッセージ設定 [未受信]
	else if(strcmp("on", mes_rmc) == 0) message = message + 0x0100;					// RMCメッセージ設定 [受信]
	else{												// 入力エラー [RMCメッセージ]

		printf("configuration error:15_rmc = %s\n", mes_rmc);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// VTGメッセージチェック
	if(strcmp("off", mes_vtg) == 0) message = message;						// VTGメッセージ設定 [未受信]
	else if(strcmp("on", mes_vtg) == 0) message = message + 0x0200;					// VTGメッセージ設定 [受信]
	else{												// 入力エラー [VTGメッセージ]

		printf("configuration error:16_vtg = %s\n", mes_vtg);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	// ZDAメッセージチェック
	if(strcmp("off", mes_zda) == 0) message = message;						// ZDAメッセージ設定 [未受信]
	else if(strcmp("on", mes_zda) == 0) message = message + 0x0400;					// ZDAメッセージ設定 [受信]
	else{												// 入力エラー [ZDAメッセージ]

		printf("configuration error:17_zda = %s\n", mes_zda);					// エラーメッセージ
		fflush(stdout);										// バッファフラッシュ [printf表示用]
		err_flag = - 1;										// エラーチェック

	}

	m_LegacyData.mode = (unsigned short int)message;						// モード格納

	//--------------------------------------------------------------------------------------//


	//-- [デバッグmode] --------------------------------------------------------------------//

	#ifndef DEBUG_MODE										// デバッグ表示開始

	printf("\n[mode]\n");										// label
	printf("total = %4d\n", message);								// total
	printf("GGA   = %4d\n", (message & 0x0001)      );						// GGA
	printf("GLL   = %4d\n", (message & 0x0002) >>  1);						// GLL
	printf("GNS   = %4d\n", (message & 0x0004) >>  2);						// GNS
	printf("GRS   = %4d\n", (message & 0x0008) >>  3);						// GRS
	printf("GSA   = %4d\n", (message & 0x0010) >>  4);						// GSA
	printf("GST   = %4d\n", (message & 0x0020) >>  5);						// GST
	printf("GSV   = %4d\n", (message & 0x0040) >>  6);						// GSV
	printf("HDT   = %4d\n", (message & 0x0080) >>  7);						// HDT
	printf("RMC   = %4d\n", (message & 0x0100) >>  8);						// RMC
	printf("VTG   = %4d\n", (message & 0x0200) >>  9);						// VTG
	printf("ZDA   = %4d\n", (message & 0x0400) >> 10);						// ZDA
	fflush(stdout);											// バッファフラッシュ [printf表示用]

	#endif												// デバッグ表示終了

	//--------------------------------------------------------------------------------------//


	//-- [シリアルポートオープン] ----------------------------------------------------------//

	// エラーチェック
	if(err_flag == - 1){										// コンフィギュレーション入力エラー

		return RTC::RTC_ERROR;									// 戻り値 [異常終了]

	}else{

		// シリアルポートオープン
		rs232c_init(&fd, &saio, &oldtio, &newtio, modemdevice, num_cflag);			// シリアルポート初期化関数
		return RTC::RTC_OK;									// 戻り値 [正常終了]

	}

	//--------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t GpsService::onDeactivated(RTC::UniqueId ec_id)
{


	//-- [シリアルポートクローズ] ----------------------------------------------------------//

	// バッファクリア
	if(wait_flag == 0) res = read(fd, buf, BUFSIZE);						// データ受信

	// コマンドセット
	strcpy(send, "dm\r\n");										// 出力設定 [終了]

	// コマンド送信
	err = write(fd, send, strlen(send));								// データ送信

	// シリアルポートクローズ
	rs232c_final(&fd, &oldtio);									// シリアルポート終了処理関数

	//--------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t GpsService::onExecute(RTC::UniqueId ec_id)
{
	//--------------------------------------------------------------------------------------//
	// [check]                                                                             -//
	//  check =  0 -> GGAメッセージ送信     check =  1 -> GGAメッセージ受信                -//
	//  check =  2 -> GLLメッセージ送信     check =  3 -> GLLメッセージ受信                -//
	//  check =  4 -> GNSメッセージ送信     check =  5 -> GNSメッセージ受信                -//
	//  check =  6 -> GRSメッセージ送信     check =  7 -> GRSメッセージ受信                -//
	//  check =  8 -> GSAメッセージ送信     check =  9 -> GSAメッセージ受信                -//
	//  check = 10 -> GSTメッセージ送信     check = 11 -> GSTメッセージ受信                -//
	//  check = 12 -> GSVメッセージ送信     check = 13 -> GSVメッセージ受信                -//
	//  check = 14 -> HDTメッセージ送信     check = 15 -> HDTメッセージ受信                -//
	//  check = 16 -> RMCメッセージ送信     check = 17 -> RMCメッセージ受信                -//
	//  check = 18 -> VTGメッセージ送信     check = 19 -> VTGメッセージ受信                -//
	//  check = 20 -> ZDAメッセージ送信     check = 21 -> ZDAメッセージ受信                -//
	//--------------------------------------------------------------------------------------//


	//-- [データ送信] ----------------------------------------------------------------------//


	//-- [タイムアウト処理] ----------------------------------------------------------------//

	if((gettimeofday_sec() - now_time) >= timeout){							// タイムアウトチェック

		// コマンドセット
		strcpy(send, "dm\r\n");									// 停止メッセージ

		// コマンド送信
		err = write(fd, send, strlen(send));							// データ送信

		// 現在時刻取得
		now_time = gettimeofday_sec();								// 現在時刻更新

		// スキップ処理
		cbuf[0] = 0x00;										// 終端文字処理
		num = 0;										// 番号リセット
		if(check % 2 == 1) check++;								// タイムアウト
		if(check == 22) check = 0;								// ループ処理

	}

	//--------------------------------------------------------------------------------------//


	switch(check){


		//-- [GGAメッセージ送信] -------------------------------------------------------//

		case 0:											// GGAメッセージ送信

			if((message & 0x0001) == 0x0001){						// GGAメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[0] == 1){

					for(i = 0; i <= (int)strlen(gga[0]); i++)
						m_LegacyData.gga.field00[i] = gga[0][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[1]); i++)
						m_LegacyData.gga.field01[i] = gga[1][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[2]); i++)
						m_LegacyData.gga.field02[i] = gga[2][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[3]); i++)
						m_LegacyData.gga.field03[i] = gga[3][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[4]); i++)
						m_LegacyData.gga.field04[i] = gga[4][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[5]); i++)
						m_LegacyData.gga.field05[i] = gga[5][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[6]); i++)
						m_LegacyData.gga.field06[i] = gga[6][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[7]); i++)
						m_LegacyData.gga.field07[i] = gga[7][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[8]); i++)
						m_LegacyData.gga.field08[i] = gga[8][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[9]); i++)
						m_LegacyData.gga.field09[i] = gga[9][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[10]); i++)
						m_LegacyData.gga.field10[i] = gga[10][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[11]); i++)
						m_LegacyData.gga.field11[i] = gga[11][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[12]); i++)
						m_LegacyData.gga.field12[i] = gga[12][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[13]); i++)
						m_LegacyData.gga.field13[i] = gga[13][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[14]); i++)
						m_LegacyData.gga.field14[i] = gga[14][i];		// GGAメッセージ格納
					for(i = 0; i <= (int)strlen(gga[15]); i++)
						m_LegacyData.gga.field15[i] = gga[15][i];		// GGAメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGGA] ---------------------------------------------//

				#ifndef DEBUG_GGA							// デバッグ表示開始

				printf("\n[gga_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gga[0], gga[1], gga[2], gga[3], gga[4],
					gga[5], gga[6], gga[7], gga[8], gga[9],
					gga[10], gga[11], gga[12], gga[13], gga[14],
					gga[15]);							// GPGGA
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 1;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 16; j++){

					strcpy(gga[j], "");						// 初期化 [GPGGA]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GGA:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 2;								// スキップ [GGA -> GLL]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GLLメッセージ送信] -------------------------------------------------------//

		case 2:											// GLLメッセージ送信

			if((message & 0x0002) == 0x0002){						// GLLメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[1] == 1){

					for(i = 0; i <= (int)strlen(gll[0]); i++)
						m_LegacyData.gll.field00[i] = gll[0][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[1]); i++)
						m_LegacyData.gll.field01[i] = gll[1][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[2]); i++)
						m_LegacyData.gll.field02[i] = gll[2][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[3]); i++)
						m_LegacyData.gll.field03[i] = gll[3][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[4]); i++)
						m_LegacyData.gll.field04[i] = gll[4][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[5]); i++)
						m_LegacyData.gll.field05[i] = gll[5][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[6]); i++)
						m_LegacyData.gll.field06[i] = gll[6][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[7]); i++)
						m_LegacyData.gll.field07[i] = gll[7][i];		// GLLメッセージ格納
					for(i = 0; i <= (int)strlen(gll[8]); i++)
						m_LegacyData.gll.field08[i] = gll[8][i];		// GLLメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGLL] ---------------------------------------------//

				#ifndef DEBUG_GLL							// デバッグ表示開始

				printf("\n[gll_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gll[0], gll[1], gll[2], gll[3], gll[4],
					gll[5], gll[6], gll[7], gll[8]);				// GNGLL
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 3;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 9; j++){

					strcpy(gll[j], "");						// 初期化 [GNGLL]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GLL:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 4;								// スキップ [GLL -> GNS]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GNSメッセージ送信] -------------------------------------------------------//

		case 4:											// GNSメッセージ送信

			if((message & 0x0004) == 0x0004){						// GNSメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[2] == 1){

					for(i = 0; i <= (int)strlen(gns[0]); i++)
						m_LegacyData.gns.field00[i] = gns[0][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[1]); i++)
						m_LegacyData.gns.field01[i] = gns[1][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[2]); i++)
						m_LegacyData.gns.field02[i] = gns[2][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[3]); i++)
						m_LegacyData.gns.field03[i] = gns[3][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[4]); i++)
						m_LegacyData.gns.field04[i] = gns[4][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[5]); i++)
						m_LegacyData.gns.field05[i] = gns[5][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[6]); i++)
						m_LegacyData.gns.field06[i] = gns[6][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[7]); i++)
						m_LegacyData.gns.field07[i] = gns[7][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[8]); i++)
						m_LegacyData.gns.field08[i] = gns[8][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[9]); i++)
						m_LegacyData.gns.field09[i] = gns[9][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[10]); i++)
						m_LegacyData.gns.field10[i] = gns[10][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[11]); i++)
						m_LegacyData.gns.field11[i] = gns[11][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gns[12]); i++)
						m_LegacyData.gns.field12[i] = gns[12][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gns[0]); i++)
						m_LegacyData.gns.gp_field00[i] = gp_gns[0][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gns[1]); i++)
						m_LegacyData.gns.gp_field01[i] = gp_gns[1][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gns[7]); i++)
						m_LegacyData.gns.gp_field07[i] = gp_gns[7][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gns[11]); i++)
						m_LegacyData.gns.gp_field11[i] = gp_gns[11][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gns[12]); i++)
						m_LegacyData.gns.gp_field12[i] = gp_gns[12][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gns[0]); i++)
						m_LegacyData.gns.gl_field00[i] = gl_gns[0][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gns[1]); i++)
						m_LegacyData.gns.gl_field01[i] = gl_gns[1][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gns[7]); i++)
						m_LegacyData.gns.gl_field07[i] = gl_gns[7][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gns[11]); i++)
						m_LegacyData.gns.gl_field11[i] = gl_gns[11][i];		// GNSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gns[12]); i++)
						m_LegacyData.gns.gl_field12[i] = gl_gns[12][i];		// GNSメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGNS] ---------------------------------------------//

				#ifndef DEBUG_GNS							// デバッグ表示開始

				printf("\n[gns_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gns[0], gns[1], gns[2], gns[3], gns[4],
					gns[5], gns[6], gns[7], gns[8], gns[9],
					gns[10], gns[11], gns[12]);					// GNGNS
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_gns[0], gp_gns[1], gp_gns[2], gp_gns[3], gp_gns[4],
					gp_gns[5], gp_gns[6], gp_gns[7], gp_gns[8], gp_gns[9],
					gp_gns[10], gp_gns[11], gp_gns[12]);				// GPGNS
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_gns[0], gl_gns[1], gl_gns[2], gl_gns[3], gl_gns[4],
					gl_gns[5], gl_gns[6], gl_gns[7], gl_gns[8], gl_gns[9],
					gl_gns[10], gl_gns[11], gl_gns[12]);				// GNGNS
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 5;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 13; j++){

					strcpy(gns[j], "");						// 初期化 [GNGNS]
					strcpy(gp_gns[j], "");						// 初期化 [GPGNS]
					strcpy(gl_gns[j], "");						// 初期化 [GLGNS]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GNS:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 6;								// スキップ [GNS -> GRS]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GRSメッセージ送信] -------------------------------------------------------//

		case 6:											// GRSメッセージ送信

			if((message & 0x0008) == 0x0008){						// GRSメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[3] == 1){

					for(i = 0; i <= (int)strlen(gp_grs[0]); i++)
						m_LegacyData.grs.gp_field00[i] = gp_grs[0][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[1]); i++)
						m_LegacyData.grs.gp_field01[i] = gp_grs[1][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[2]); i++)
						m_LegacyData.grs.gp_field02[i] = gp_grs[2][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[3]); i++)
						m_LegacyData.grs.gp_field03_01[i] = gp_grs[3][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[4]); i++)
						m_LegacyData.grs.gp_field03_02[i] = gp_grs[4][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[5]); i++)
						m_LegacyData.grs.gp_field03_03[i] = gp_grs[5][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[6]); i++)
						m_LegacyData.grs.gp_field03_04[i] = gp_grs[6][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[7]); i++)
						m_LegacyData.grs.gp_field03_05[i] = gp_grs[7][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[8]); i++)
						m_LegacyData.grs.gp_field03_06[i] = gp_grs[8][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[9]); i++)
						m_LegacyData.grs.gp_field03_07[i] = gp_grs[9][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[10]); i++)
						m_LegacyData.grs.gp_field03_08[i] = gp_grs[10][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[11]); i++)
						m_LegacyData.grs.gp_field03_09[i] = gp_grs[11][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[12]); i++)
						m_LegacyData.grs.gp_field03_10[i] = gp_grs[12][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[13]); i++)
						m_LegacyData.grs.gp_field03_11[i] = gp_grs[13][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[14]); i++)
						m_LegacyData.grs.gp_field03_12[i] = gp_grs[14][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gp_grs[15]); i++)
						m_LegacyData.grs.gp_field04[i] = gp_grs[15][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[0]); i++)
						m_LegacyData.grs.gl_field00[i] = gl_grs[0][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[1]); i++)
						m_LegacyData.grs.gl_field01[i] = gl_grs[1][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[2]); i++)
						m_LegacyData.grs.gl_field02[i] = gl_grs[2][i];		// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[3]); i++)
						m_LegacyData.grs.gl_field03_01[i] = gl_grs[3][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[4]); i++)
						m_LegacyData.grs.gl_field03_02[i] = gl_grs[4][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[5]); i++)
						m_LegacyData.grs.gl_field03_03[i] = gl_grs[5][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[6]); i++)
						m_LegacyData.grs.gl_field03_04[i] = gl_grs[6][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[7]); i++)
						m_LegacyData.grs.gl_field03_05[i] = gl_grs[7][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[8]); i++)
						m_LegacyData.grs.gl_field03_06[i] = gl_grs[8][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[9]); i++)
						m_LegacyData.grs.gl_field03_07[i] = gl_grs[9][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[10]); i++)
						m_LegacyData.grs.gl_field03_08[i] = gl_grs[10][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[11]); i++)
						m_LegacyData.grs.gl_field03_09[i] = gl_grs[11][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[12]); i++)
						m_LegacyData.grs.gl_field03_10[i] = gl_grs[12][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[13]); i++)
						m_LegacyData.grs.gl_field03_11[i] = gl_grs[13][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[14]); i++)
						m_LegacyData.grs.gl_field03_12[i] = gl_grs[14][i];	// GRSメッセージ格納
					for(i = 0; i <= (int)strlen(gl_grs[15]); i++)
						m_LegacyData.grs.gl_field04[i] = gl_grs[15][i];		// GRSメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGRS] ---------------------------------------------//

				#ifndef DEBUG_GRS							// デバッグ表示開始

				printf("\n[grs_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_grs[0], gp_grs[1], gp_grs[2], gp_grs[3], gp_grs[4],
					gp_grs[5], gp_grs[6], gp_grs[7], gp_grs[8], gp_grs[9],
					gp_grs[10], gp_grs[11], gp_grs[12], gp_grs[13], gp_grs[14],
					gp_grs[15]);							// GPGRS
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_grs[0], gl_grs[1], gl_grs[2], gl_grs[3], gl_grs[4],
					gl_grs[5], gl_grs[6], gl_grs[7], gl_grs[8], gl_grs[9],
					gl_grs[10], gl_grs[11], gl_grs[12], gl_grs[13], gl_grs[14],
					gl_grs[15]);							// GLGRS
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 7;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 16; j++){

					strcpy(gp_grs[j], "");						// 初期化 [GPGRS]
					strcpy(gl_grs[j], "");						// 初期化 [GLGRS]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GRS:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 8;								// スキップ [GRS -> GSA]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GSAメッセージ送信] -------------------------------------------------------//

		case 8:											// GSAメッセージ送信

			if((message & 0x0010) == 0x0010){						// GSAメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[4] == 1){

					for(i = 0; i <= (int)strlen(gp_gsa[0]); i++)
						m_LegacyData.gsa.gp_field00[i] = gp_gsa[0][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[1]); i++)
						m_LegacyData.gsa.gp_field01[i] = gp_gsa[1][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[2]); i++)
						m_LegacyData.gsa.gp_field02[i] = gp_gsa[2][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[3]); i++)
						m_LegacyData.gsa.gp_field03_01[i] = gp_gsa[3][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[4]); i++)
						m_LegacyData.gsa.gp_field03_02[i] = gp_gsa[4][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[5]); i++)
						m_LegacyData.gsa.gp_field03_03[i] = gp_gsa[5][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[6]); i++)
						m_LegacyData.gsa.gp_field03_04[i] = gp_gsa[6][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[7]); i++)
						m_LegacyData.gsa.gp_field03_05[i] = gp_gsa[7][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[8]); i++)
						m_LegacyData.gsa.gp_field03_06[i] = gp_gsa[8][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[9]); i++)
						m_LegacyData.gsa.gp_field03_07[i] = gp_gsa[9][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[10]); i++)
						m_LegacyData.gsa.gp_field03_08[i] = gp_gsa[10][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[11]); i++)
						m_LegacyData.gsa.gp_field03_09[i] = gp_gsa[11][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[12]); i++)
						m_LegacyData.gsa.gp_field03_10[i] = gp_gsa[12][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[13]); i++)
						m_LegacyData.gsa.gp_field03_11[i] = gp_gsa[13][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[14]); i++)
						m_LegacyData.gsa.gp_field03_12[i] = gp_gsa[14][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[15]); i++)
						m_LegacyData.gsa.gp_field04[i] = gp_gsa[15][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[16]); i++)
						m_LegacyData.gsa.gp_field05[i] = gp_gsa[16][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[17]); i++)
						m_LegacyData.gsa.gp_field06[i] = gp_gsa[17][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsa[18]); i++)
						m_LegacyData.gsa.gp_field07[i] = gp_gsa[18][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[0]); i++)
						m_LegacyData.gsa.gl_field00[i] = gl_gsa[0][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[1]); i++)
						m_LegacyData.gsa.gl_field01[i] = gl_gsa[1][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[2]); i++)
						m_LegacyData.gsa.gl_field02[i] = gl_gsa[2][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[3]); i++)
						m_LegacyData.gsa.gl_field03_01[i] = gl_gsa[3][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[4]); i++)
						m_LegacyData.gsa.gl_field03_02[i] = gl_gsa[4][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[5]); i++)
						m_LegacyData.gsa.gl_field03_03[i] = gl_gsa[5][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[6]); i++)
						m_LegacyData.gsa.gl_field03_04[i] = gl_gsa[6][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[7]); i++)
						m_LegacyData.gsa.gl_field03_05[i] = gl_gsa[7][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[8]); i++)
						m_LegacyData.gsa.gl_field03_06[i] = gl_gsa[8][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[9]); i++)
						m_LegacyData.gsa.gl_field03_07[i] = gl_gsa[9][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[10]); i++)
						m_LegacyData.gsa.gl_field03_08[i] = gl_gsa[10][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[11]); i++)
						m_LegacyData.gsa.gl_field03_09[i] = gl_gsa[11][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[12]); i++)
						m_LegacyData.gsa.gl_field03_10[i] = gl_gsa[12][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[13]); i++)
						m_LegacyData.gsa.gl_field03_11[i] = gl_gsa[13][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[14]); i++)
						m_LegacyData.gsa.gl_field03_12[i] = gl_gsa[14][i];	// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[15]); i++)
						m_LegacyData.gsa.gl_field04[i] = gl_gsa[15][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[16]); i++)
						m_LegacyData.gsa.gl_field05[i] = gl_gsa[16][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[17]); i++)
						m_LegacyData.gsa.gl_field06[i] = gl_gsa[17][i];		// GSAメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsa[18]); i++)
						m_LegacyData.gsa.gl_field07[i] = gl_gsa[18][i];		// GSAメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGSA] ---------------------------------------------//

				#ifndef DEBUG_GSA							// デバッグ表示開始

				printf("\n[gsa_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_gsa[0], gp_gsa[1], gp_gsa[2], gp_gsa[3], gp_gsa[4],
					gp_gsa[5], gp_gsa[6], gp_gsa[7], gp_gsa[8], gp_gsa[9],
					gp_gsa[10], gp_gsa[11], gp_gsa[12], gp_gsa[13], gp_gsa[14],
					gp_gsa[15], gp_gsa[16], gp_gsa[17], gp_gsa[18]);		// GPGSA
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_gsa[0], gl_gsa[1], gl_gsa[2], gl_gsa[3], gl_gsa[4],
					gl_gsa[5], gl_gsa[6], gl_gsa[7], gl_gsa[8], gl_gsa[9],
					gl_gsa[10], gl_gsa[11], gl_gsa[12], gl_gsa[13], gl_gsa[14],
					gl_gsa[15], gl_gsa[16], gl_gsa[17], gl_gsa[18]);		// GLGSA
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 9;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 19; j++){

					strcpy(gp_gsa[j], "");						// 初期化 [GPGSA]
					strcpy(gl_gsa[j], "");						// 初期化 [GLGSA]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GSA:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 10;								// スキップ [GSA -> GST]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GSTメッセージ送信] -------------------------------------------------------//

		case 10:										// GSTメッセージ送信

			if((message & 0x0020) == 0x0020){						// GSTメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[5] == 1){

					for(i = 0; i <= (int)strlen(gst[0]); i++)
						m_LegacyData.gst.field00[i] = gst[0][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[1]); i++)
						m_LegacyData.gst.field01[i] = gst[1][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[2]); i++)
						m_LegacyData.gst.field02[i] = gst[2][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[3]); i++)
						m_LegacyData.gst.field03[i] = gst[3][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[4]); i++)
						m_LegacyData.gst.field04[i] = gst[4][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[5]); i++)
						m_LegacyData.gst.field05[i] = gst[5][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[6]); i++)
						m_LegacyData.gst.field06[i] = gst[6][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[7]); i++)
						m_LegacyData.gst.field07[i] = gst[7][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[8]); i++)
						m_LegacyData.gst.field08[i] = gst[8][i];		// GSTメッセージ格納
					for(i = 0; i <= (int)strlen(gst[9]); i++)
						m_LegacyData.gst.field09[i] = gst[9][i];		// GSTメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGST] ---------------------------------------------//

				#ifndef DEBUG_GST							// デバッグ表示開始

				printf("\n[gst_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gst[0], gst[1], gst[2], gst[3], gst[4],
					gst[5], gst[6], gst[7], gst[8], gst[9]);			// GNGST
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 11;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 10; j++){

					strcpy(gst[j], "");						// 初期化 [GNGST]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GST:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 12;								// スキップ [GST -> GSV]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [GSVメッセージ送信] -------------------------------------------------------//

		case 12:										// GSVメッセージ送信

			if((message & 0x0040) == 0x0040){						// GSVメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[6] == 1){

					for(i = 0; i <= (int)strlen(gp_gsv[0][0]); i++)
						m_LegacyData.gsv.gp1_field00[i]     = gp_gsv[0][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][1]); i++)
						m_LegacyData.gsv.gp1_field01[i]     = gp_gsv[0][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][2]); i++)
						m_LegacyData.gsv.gp1_field02[i]     = gp_gsv[0][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][3]); i++)
						m_LegacyData.gsv.gp1_field03[i]     = gp_gsv[0][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][4]); i++)
						m_LegacyData.gsv.gp1_field04_1_1[i] = gp_gsv[0][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][5]); i++)
						m_LegacyData.gsv.gp1_field04_1_2[i] = gp_gsv[0][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][6]); i++)
						m_LegacyData.gsv.gp1_field04_1_3[i] = gp_gsv[0][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][7]); i++)
						m_LegacyData.gsv.gp1_field04_1_4[i] = gp_gsv[0][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][8]); i++)
						m_LegacyData.gsv.gp1_field04_2_1[i] = gp_gsv[0][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][9]); i++)
						m_LegacyData.gsv.gp1_field04_2_2[i] = gp_gsv[0][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][10]); i++)
						m_LegacyData.gsv.gp1_field04_2_3[i] = gp_gsv[0][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][11]); i++)
						m_LegacyData.gsv.gp1_field04_2_4[i] = gp_gsv[0][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][12]); i++)
						m_LegacyData.gsv.gp1_field04_3_1[i] = gp_gsv[0][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][13]); i++)
						m_LegacyData.gsv.gp1_field04_3_2[i] = gp_gsv[0][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][14]); i++)
						m_LegacyData.gsv.gp1_field04_3_3[i] = gp_gsv[0][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][15]); i++)
						m_LegacyData.gsv.gp1_field04_3_4[i] = gp_gsv[0][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][16]); i++)
						m_LegacyData.gsv.gp1_field04_4_1[i] = gp_gsv[0][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][17]); i++)
						m_LegacyData.gsv.gp1_field04_4_2[i] = gp_gsv[0][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][18]); i++)
						m_LegacyData.gsv.gp1_field04_4_3[i] = gp_gsv[0][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][19]); i++)
						m_LegacyData.gsv.gp1_field04_4_4[i] = gp_gsv[0][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[0][20]); i++)
						m_LegacyData.gsv.gp1_field05[i]     = gp_gsv[0][20][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][0]); i++)
						m_LegacyData.gsv.gp2_field00[i]     = gp_gsv[1][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][1]); i++)
						m_LegacyData.gsv.gp2_field01[i]     = gp_gsv[1][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][2]); i++)
						m_LegacyData.gsv.gp2_field02[i]     = gp_gsv[1][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][3]); i++)
						m_LegacyData.gsv.gp2_field03[i]     = gp_gsv[1][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][4]); i++)
						m_LegacyData.gsv.gp2_field04_1_1[i] = gp_gsv[1][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][5]); i++)
						m_LegacyData.gsv.gp2_field04_1_2[i] = gp_gsv[1][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][6]); i++)
						m_LegacyData.gsv.gp2_field04_1_3[i] = gp_gsv[1][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][7]); i++)
						m_LegacyData.gsv.gp2_field04_1_4[i] = gp_gsv[1][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][8]); i++)
						m_LegacyData.gsv.gp2_field04_2_1[i] = gp_gsv[1][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][9]); i++)
						m_LegacyData.gsv.gp2_field04_2_2[i] = gp_gsv[1][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][10]); i++)
						m_LegacyData.gsv.gp2_field04_2_3[i] = gp_gsv[1][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][11]); i++)
						m_LegacyData.gsv.gp2_field04_2_4[i] = gp_gsv[1][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][12]); i++)
						m_LegacyData.gsv.gp2_field04_3_1[i] = gp_gsv[1][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][13]); i++)
						m_LegacyData.gsv.gp2_field04_3_2[i] = gp_gsv[1][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][14]); i++)
						m_LegacyData.gsv.gp2_field04_3_3[i] = gp_gsv[1][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][15]); i++)
						m_LegacyData.gsv.gp2_field04_3_4[i] = gp_gsv[1][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][16]); i++)
						m_LegacyData.gsv.gp2_field04_4_1[i] = gp_gsv[1][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][17]); i++)
						m_LegacyData.gsv.gp2_field04_4_2[i] = gp_gsv[1][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][18]); i++)
						m_LegacyData.gsv.gp2_field04_4_3[i] = gp_gsv[1][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][19]); i++)
						m_LegacyData.gsv.gp2_field04_4_4[i] = gp_gsv[1][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[1][20]); i++)
						m_LegacyData.gsv.gp2_field05[i]     = gp_gsv[1][20][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][0]); i++)
						m_LegacyData.gsv.gp3_field00[i]     = gp_gsv[2][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][1]); i++)
						m_LegacyData.gsv.gp3_field01[i]     = gp_gsv[2][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][2]); i++)
						m_LegacyData.gsv.gp3_field02[i]     = gp_gsv[2][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][3]); i++)
						m_LegacyData.gsv.gp3_field03[i]     = gp_gsv[2][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][4]); i++)
						m_LegacyData.gsv.gp3_field04_1_1[i] = gp_gsv[2][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][5]); i++)
						m_LegacyData.gsv.gp3_field04_1_2[i] = gp_gsv[2][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][6]); i++)
						m_LegacyData.gsv.gp3_field04_1_3[i] = gp_gsv[2][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][7]); i++)
						m_LegacyData.gsv.gp3_field04_1_4[i] = gp_gsv[2][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][8]); i++)
						m_LegacyData.gsv.gp3_field04_2_1[i] = gp_gsv[2][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][9]); i++)
						m_LegacyData.gsv.gp3_field04_2_2[i] = gp_gsv[2][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][10]); i++)
						m_LegacyData.gsv.gp3_field04_2_3[i] = gp_gsv[2][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][11]); i++)
						m_LegacyData.gsv.gp3_field04_2_4[i] = gp_gsv[2][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][12]); i++)
						m_LegacyData.gsv.gp3_field04_3_1[i] = gp_gsv[2][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][13]); i++)
						m_LegacyData.gsv.gp3_field04_3_2[i] = gp_gsv[2][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][14]); i++)
						m_LegacyData.gsv.gp3_field04_3_3[i] = gp_gsv[2][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][15]); i++)
						m_LegacyData.gsv.gp3_field04_3_4[i] = gp_gsv[2][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][16]); i++)
						m_LegacyData.gsv.gp3_field04_4_1[i] = gp_gsv[2][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][17]); i++)
						m_LegacyData.gsv.gp3_field04_4_2[i] = gp_gsv[2][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][18]); i++)
						m_LegacyData.gsv.gp3_field04_4_3[i] = gp_gsv[2][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][19]); i++)
						m_LegacyData.gsv.gp3_field04_4_4[i] = gp_gsv[2][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gp_gsv[2][20]); i++)
						m_LegacyData.gsv.gp3_field05[i]     = gp_gsv[2][20][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][0]); i++)
						m_LegacyData.gsv.gl1_field00[i]     = gl_gsv[0][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][1]); i++)
						m_LegacyData.gsv.gl1_field01[i]     = gl_gsv[0][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][2]); i++)
						m_LegacyData.gsv.gl1_field02[i]     = gl_gsv[0][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][3]); i++)
						m_LegacyData.gsv.gl1_field03[i]     = gl_gsv[0][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][4]); i++)
						m_LegacyData.gsv.gl1_field04_1_1[i] = gl_gsv[0][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][5]); i++)
						m_LegacyData.gsv.gl1_field04_1_2[i] = gl_gsv[0][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][6]); i++)
						m_LegacyData.gsv.gl1_field04_1_3[i] = gl_gsv[0][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][7]); i++)
						m_LegacyData.gsv.gl1_field04_1_4[i] = gl_gsv[0][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][8]); i++)
						m_LegacyData.gsv.gl1_field04_2_1[i] = gl_gsv[0][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][9]); i++)
						m_LegacyData.gsv.gl1_field04_2_2[i] = gl_gsv[0][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][10]); i++)
						m_LegacyData.gsv.gl1_field04_2_3[i] = gl_gsv[0][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][11]); i++)
						m_LegacyData.gsv.gl1_field04_2_4[i] = gl_gsv[0][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][12]); i++)
						m_LegacyData.gsv.gl1_field04_3_1[i] = gl_gsv[0][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][13]); i++)
						m_LegacyData.gsv.gl1_field04_3_2[i] = gl_gsv[0][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][14]); i++)
						m_LegacyData.gsv.gl1_field04_3_3[i] = gl_gsv[0][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][15]); i++)
						m_LegacyData.gsv.gl1_field04_3_4[i] = gl_gsv[0][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][16]); i++)
						m_LegacyData.gsv.gl1_field04_4_1[i] = gl_gsv[0][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][17]); i++)
						m_LegacyData.gsv.gl1_field04_4_2[i] = gl_gsv[0][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][18]); i++)
						m_LegacyData.gsv.gl1_field04_4_3[i] = gl_gsv[0][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][19]); i++)
						m_LegacyData.gsv.gl1_field04_4_4[i] = gl_gsv[0][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[0][20]); i++)
						m_LegacyData.gsv.gl1_field05[i]     = gl_gsv[0][20][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][0]); i++)
						m_LegacyData.gsv.gl2_field00[i]     = gl_gsv[1][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][1]); i++)
						m_LegacyData.gsv.gl2_field01[i]     = gl_gsv[1][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][2]); i++)
						m_LegacyData.gsv.gl2_field02[i]     = gl_gsv[1][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][3]); i++)
						m_LegacyData.gsv.gl2_field03[i]     = gl_gsv[1][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][4]); i++)
						m_LegacyData.gsv.gl2_field04_1_1[i] = gl_gsv[1][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][5]); i++)
						m_LegacyData.gsv.gl2_field04_1_2[i] = gl_gsv[1][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][6]); i++)
						m_LegacyData.gsv.gl2_field04_1_3[i] = gl_gsv[1][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][7]); i++)
						m_LegacyData.gsv.gl2_field04_1_4[i] = gl_gsv[1][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][8]); i++)
						m_LegacyData.gsv.gl2_field04_2_1[i] = gl_gsv[1][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][9]); i++)
						m_LegacyData.gsv.gl2_field04_2_2[i] = gl_gsv[1][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][10]); i++)
						m_LegacyData.gsv.gl2_field04_2_3[i] = gl_gsv[1][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][11]); i++)
						m_LegacyData.gsv.gl2_field04_2_4[i] = gl_gsv[1][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][12]); i++)
						m_LegacyData.gsv.gl2_field04_3_1[i] = gl_gsv[1][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][13]); i++)
						m_LegacyData.gsv.gl2_field04_3_2[i] = gl_gsv[1][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][14]); i++)
						m_LegacyData.gsv.gl2_field04_3_3[i] = gl_gsv[1][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][15]); i++)
						m_LegacyData.gsv.gl2_field04_3_4[i] = gl_gsv[1][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][16]); i++)
						m_LegacyData.gsv.gl2_field04_4_1[i] = gl_gsv[1][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][17]); i++)
						m_LegacyData.gsv.gl2_field04_4_2[i] = gl_gsv[1][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][18]); i++)
						m_LegacyData.gsv.gl2_field04_4_3[i] = gl_gsv[1][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][19]); i++)
						m_LegacyData.gsv.gl2_field04_4_4[i] = gl_gsv[1][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[1][20]); i++)
						m_LegacyData.gsv.gl2_field05[i]     = gl_gsv[1][20][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][0]); i++)
						m_LegacyData.gsv.gl3_field00[i]     = gl_gsv[2][0][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][1]); i++)
						m_LegacyData.gsv.gl3_field01[i]     = gl_gsv[2][1][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][2]); i++)
						m_LegacyData.gsv.gl3_field02[i]     = gl_gsv[2][2][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][3]); i++)
						m_LegacyData.gsv.gl3_field03[i]     = gl_gsv[2][3][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][4]); i++)
						m_LegacyData.gsv.gl3_field04_1_1[i] = gl_gsv[2][4][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][5]); i++)
						m_LegacyData.gsv.gl3_field04_1_2[i] = gl_gsv[2][5][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][6]); i++)
						m_LegacyData.gsv.gl3_field04_1_3[i] = gl_gsv[2][6][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][7]); i++)
						m_LegacyData.gsv.gl3_field04_1_4[i] = gl_gsv[2][7][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][8]); i++)
						m_LegacyData.gsv.gl3_field04_2_1[i] = gl_gsv[2][8][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][9]); i++)
						m_LegacyData.gsv.gl3_field04_2_2[i] = gl_gsv[2][9][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][10]); i++)
						m_LegacyData.gsv.gl3_field04_2_3[i] = gl_gsv[2][10][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][11]); i++)
						m_LegacyData.gsv.gl3_field04_2_4[i] = gl_gsv[2][11][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][12]); i++)
						m_LegacyData.gsv.gl3_field04_3_1[i] = gl_gsv[2][12][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][13]); i++)
						m_LegacyData.gsv.gl3_field04_3_2[i] = gl_gsv[2][13][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][14]); i++)
						m_LegacyData.gsv.gl3_field04_3_3[i] = gl_gsv[2][14][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][15]); i++)
						m_LegacyData.gsv.gl3_field04_3_4[i] = gl_gsv[2][15][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][16]); i++)
						m_LegacyData.gsv.gl3_field04_4_1[i] = gl_gsv[2][16][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][17]); i++)
						m_LegacyData.gsv.gl3_field04_4_2[i] = gl_gsv[2][17][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][18]); i++)
						m_LegacyData.gsv.gl3_field04_4_3[i] = gl_gsv[2][18][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][19]); i++)
						m_LegacyData.gsv.gl3_field04_4_4[i] = gl_gsv[2][19][i];	// GSVメッセージ格納
					for(i = 0; i <= (int)strlen(gl_gsv[2][20]); i++)
						m_LegacyData.gsv.gl3_field05[i]     = gl_gsv[2][20][i];	// GSVメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグGSV] ---------------------------------------------//

				#ifndef DEBUG_GSV							// デバッグ表示開始

				printf("\n[gsv_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_gsv[0][0], gp_gsv[0][1], gp_gsv[0][2], gp_gsv[0][3],
					gp_gsv[0][4], gp_gsv[0][5], gp_gsv[0][6], gp_gsv[0][7],
					gp_gsv[0][8], gp_gsv[0][9], gp_gsv[0][10], gp_gsv[0][11],
					gp_gsv[0][12], gp_gsv[0][13], gp_gsv[0][14], gp_gsv[0][15],
					gp_gsv[0][16], gp_gsv[0][17], gp_gsv[0][18], gp_gsv[0][19],
					gp_gsv[0][20]);							// GPGSV
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_gsv[1][0], gp_gsv[1][1], gp_gsv[1][2], gp_gsv[1][3],
					gp_gsv[1][4], gp_gsv[1][5], gp_gsv[1][6], gp_gsv[1][7],
					gp_gsv[1][8], gp_gsv[1][9], gp_gsv[1][10], gp_gsv[1][11],
					gp_gsv[1][12], gp_gsv[1][13], gp_gsv[1][14], gp_gsv[1][15],
					gp_gsv[1][16], gp_gsv[1][17], gp_gsv[1][18], gp_gsv[1][19],
					gp_gsv[1][20]);							// GPGSV
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gp_gsv[2][0], gp_gsv[2][1], gp_gsv[2][2], gp_gsv[2][3],
					gp_gsv[2][4], gp_gsv[2][5], gp_gsv[2][6], gp_gsv[2][7],
					gp_gsv[2][8], gp_gsv[2][9], gp_gsv[2][10], gp_gsv[2][11],
					gp_gsv[2][12], gp_gsv[2][13], gp_gsv[2][14], gp_gsv[2][15],
					gp_gsv[2][16], gp_gsv[2][17], gp_gsv[2][18], gp_gsv[2][19],
					gp_gsv[2][20]);							// GPGSV
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_gsv[0][0], gl_gsv[0][1], gl_gsv[0][2], gl_gsv[0][3],
					gl_gsv[0][4], gl_gsv[0][5], gl_gsv[0][6], gl_gsv[0][7],
					gl_gsv[0][8], gl_gsv[0][9], gl_gsv[0][10], gl_gsv[0][11],
					gl_gsv[0][12], gl_gsv[0][13], gl_gsv[0][14], gl_gsv[0][15],
					gl_gsv[0][16], gl_gsv[0][17], gl_gsv[0][18], gl_gsv[0][19],
					gl_gsv[0][20]);							// GLGSV
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_gsv[1][0], gl_gsv[1][1], gl_gsv[1][2], gl_gsv[1][3],
					gl_gsv[1][4], gl_gsv[1][5], gl_gsv[1][6], gl_gsv[1][7],
					gl_gsv[1][8], gl_gsv[1][9], gl_gsv[1][10], gl_gsv[1][11],
					gl_gsv[1][12], gl_gsv[1][13], gl_gsv[1][14], gl_gsv[1][15],
					gl_gsv[1][16], gl_gsv[1][17], gl_gsv[1][18], gl_gsv[1][19],
					gl_gsv[1][20]);							// GLGSV
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					gl_gsv[2][0], gl_gsv[2][1], gl_gsv[2][2], gl_gsv[2][3],
					gl_gsv[2][4], gl_gsv[2][5], gl_gsv[2][6], gl_gsv[2][7],
					gl_gsv[2][8], gl_gsv[2][9], gl_gsv[2][10], gl_gsv[2][11],
					gl_gsv[2][12], gl_gsv[2][13], gl_gsv[2][14], gl_gsv[2][15],
					gl_gsv[2][16], gl_gsv[2][17], gl_gsv[2][18], gl_gsv[2][19],
					gl_gsv[2][20]);							// GLGSV
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 13;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 21; j++){

					strcpy(gp_gsv[0][j], "");					// 初期化 [GPGSV]
					strcpy(gp_gsv[1][j], "");					// 初期化 [GPGSV]
					strcpy(gp_gsv[2][j], "");					// 初期化 [GPGSV]
					strcpy(gl_gsv[0][j], "");					// 初期化 [GLGSV]
					strcpy(gl_gsv[1][j], "");					// 初期化 [GLGSV]
					strcpy(gl_gsv[2][j], "");					// 初期化 [GLGSV]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/GSV:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 14;								// スキップ [GSV -> HDT]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [HDTメッセージ送信] -------------------------------------------------------//

		case 14:										// HDTメッセージ送信

			if((message & 0x0080) == 0x0080){						// HDTメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[7] == 1){

					for(i = 0; i <= (int)strlen(hdt[0]); i++)
						m_LegacyData.hdt.field00[i] = hdt[0][i];		// HDTメッセージ格納
					for(i = 0; i <= (int)strlen(hdt[1]); i++)
						m_LegacyData.hdt.field01[i] = hdt[1][i];		// HDTメッセージ格納
					for(i = 0; i <= (int)strlen(hdt[2]); i++)
						m_LegacyData.hdt.field02[i] = hdt[2][i];		// HDTメッセージ格納
					for(i = 0; i <= (int)strlen(hdt[3]); i++)
						m_LegacyData.hdt.field03[i] = hdt[3][i];		// HDTメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグHDT] ---------------------------------------------//

				#ifndef DEBUG_HDT							// デバッグ表示開始

				printf("\n[hdt_message]\n");						// label
				printf("%s,%s,%s,%s\n",
					hdt[0], hdt[1], hdt[2], hdt[3]);				// GNHDT
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 15;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 4; j++){

					strcpy(hdt[j], "");						// 初期化 [GNHDT]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/HDT:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 16;								// スキップ [HDT -> RMC]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [RMCメッセージ送信] -------------------------------------------------------//

		case 16:										// RMCメッセージ送信

			if((message & 0x0100) == 0x0100){						// RMCメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[8] == 1){

					for(i = 0; i <= (int)strlen(rmc[0]); i++)
						m_LegacyData.rmc.field00[i] = rmc[0][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[1]); i++)
						m_LegacyData.rmc.field01[i] = rmc[1][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[2]); i++)
						m_LegacyData.rmc.field02[i] = rmc[2][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[3]); i++)
						m_LegacyData.rmc.field03[i] = rmc[3][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[4]); i++)
						m_LegacyData.rmc.field04[i] = rmc[4][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[5]); i++)
						m_LegacyData.rmc.field05[i] = rmc[5][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[6]); i++)
						m_LegacyData.rmc.field06[i] = rmc[6][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[7]); i++)
						m_LegacyData.rmc.field07[i] = rmc[7][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[8]); i++)
						m_LegacyData.rmc.field08[i] = rmc[8][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[9]); i++)
						m_LegacyData.rmc.field09[i] = rmc[9][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[10]); i++)
						m_LegacyData.rmc.field10[i] = rmc[10][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[11]); i++)
						m_LegacyData.rmc.field11[i] = rmc[11][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[12]); i++)
						m_LegacyData.rmc.field12[i] = rmc[12][i];		// RMCメッセージ格納
					for(i = 0; i <= (int)strlen(rmc[13]); i++)
						m_LegacyData.rmc.field13[i] = rmc[13][i];		// RMCメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグRMC] ---------------------------------------------//

				#ifndef DEBUG_RMC							// デバッグ表示開始

				printf("\n[rmc_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					rmc[0], rmc[1], rmc[2], rmc[3], rmc[4],
					rmc[5], rmc[6], rmc[7], rmc[8], rmc[9],
					rmc[10], rmc[11], rmc[12], rmc[13]);				// GNRMC
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 17;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 14; j++){

					strcpy(rmc[j], "");						// 初期化 [GNRMC]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/RMC:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 18;								// スキップ [RMC -> VTG]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [VTGメッセージ送信] -------------------------------------------------------//

		case 18:										// VTGメッセージ送信

			if((message & 0x0200) == 0x0200){						// VTGメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[9] == 1){

					for(i = 0; i <= (int)strlen(vtg[0]); i++)
						m_LegacyData.vtg.field00[i] = vtg[0][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[1]); i++)
						m_LegacyData.vtg.field01[i] = vtg[1][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[2]); i++)
						m_LegacyData.vtg.field02[i] = vtg[2][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[3]); i++)
						m_LegacyData.vtg.field03[i] = vtg[3][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[4]); i++)
						m_LegacyData.vtg.field04[i] = vtg[4][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[5]); i++)
						m_LegacyData.vtg.field05[i] = vtg[5][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[6]); i++)
						m_LegacyData.vtg.field06[i] = vtg[6][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[7]); i++)
						m_LegacyData.vtg.field07[i] = vtg[7][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[8]); i++)
						m_LegacyData.vtg.field08[i] = vtg[8][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[9]); i++)
						m_LegacyData.vtg.field09[i] = vtg[9][i];		// VTGメッセージ格納
					for(i = 0; i <= (int)strlen(vtg[10]); i++)
						m_LegacyData.vtg.field10[i] = vtg[10][i];		// VTGメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグVTG] ---------------------------------------------//

				#ifndef DEBUG_VTG							// デバッグ表示開始

				printf("\n[vtg_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n",
					vtg[0], vtg[1], vtg[2], vtg[3], vtg[4],
					vtg[5], vtg[6], vtg[7], vtg[8], vtg[9],
					vtg[10]);							// GNVTG
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


				//-- [コマンド送信] --------------------------------------------//

				// モード切り替え
				check = 19;								// モード切り替え [送信 -> 受信]

				// 初期化
				num = 0;								// 番号リセット
				for(j = 0; j < 11; j++){

					strcpy(vtg[j], "");						// 初期化 [GNVTG]

				}

				// コマンドセット
				strcpy(send, "dm\r\n");							// 停止メッセージ

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// コマンドセット
				strcpy(send, "out,");							// 出力設定 [単発]
				strcat(send, serialport);						// シリアルポート設定
				strcat(send, ",/msg/nmea/VTG:");					// メッセージ
				strcat(send, sendtime);							// 受信速度
				strcat(send, "\r\n");							// 終端コード [<CR><LF>]

				// コマンド送信
				err = write(fd, send, strlen(send));					// データ送信

				// 現在時刻取得
				now_time = gettimeofday_sec();						// 現在時刻取得

				//--------------------------------------------------------------//


			}else check = 20;								// スキップ [VTG -> ZDA]

			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [ZDAメッセージ送信] -------------------------------------------------------//

		case 20:										// ZDAメッセージ送信

			if((message & 0x0400) == 0x0400){						// ZDAメッセージ送信処理


				//-- [データ格納] ----------------------------------------------//

				if(check_flag[10] == 1){

					for(i = 0; i <= (int)strlen(zda[0]); i++)
						m_LegacyData.zda.field00[i] = zda[0][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[1]); i++)
						m_LegacyData.zda.field01[i] = zda[1][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[2]); i++)
						m_LegacyData.zda.field02[i] = zda[2][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[3]); i++)
						m_LegacyData.zda.field03[i] = zda[3][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[4]); i++)
						m_LegacyData.zda.field04[i] = zda[4][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[5]); i++)
						m_LegacyData.zda.field05[i] = zda[5][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[6]); i++)
						m_LegacyData.zda.field06[i] = zda[6][i];		// ZDAメッセージ格納
					for(i = 0; i <= (int)strlen(zda[7]); i++)
						m_LegacyData.zda.field07[i] = zda[7][i];		// ZDAメッセージ格納

				}

				//--------------------------------------------------------------//


				//-- [デバッグZDA] ---------------------------------------------//

				#ifndef DEBUG_ZDA							// デバッグ表示開始

				printf("\n[zda_message]\n");						// label
				printf("%s,%s,%s,%s,%s,%s,%s,%s\n",
					zda[0], zda[1], zda[2], zda[3],
					zda[4], zda[5], zda[6], zda[7]);				// GNZDA
				fflush(stdout);								// バッファフラッシュ [printf表示用]

				#endif									// デバッグ表示終了

				//--------------------------------------------------------------//


			}


			//-- [タイムスタンプ格納] ----------------------------------------------//

			sec = (unsigned long)(atof(zda[1]));						// UTC一時格納 [sec]
			m_LegacyData.tm.sec = (sec / 10000) * 3600
				+ ((sec % 10000) / 100) * 60 + (sec % 100);				// タイムスタンプ格納 [sec]
			nsec = (unsigned long)(fmod(atof(zda[1]), 1) * 1000000000);			// UTC一時格納 [nsec]
			if((nsec % 10) != 0) nsec++;							// 四捨五入処理
			m_LegacyData.tm.nsec = nsec;							// タイムスタンプ格納 [nsec]

			//----------------------------------------------------------------------//


			//-- [デバッグtimestamp] -----------------------------------------------//

			#ifndef DEBUG_TIMESTAMP								// デバッグ表示開始

			printf("\n[timestamp]\n");							// label
			printf("%5ld.%ld\n", (sec / 10000) * 3600
				+ ((sec % 10000) / 100) * 60 + (sec % 100), nsec / 100000000);		// timestamp
			fflush(stdout);									// バッファフラッシュ [printf表示用]

			#endif										// デバッグ表示終了

			//----------------------------------------------------------------------//


			//-- [コマンド送信] ----------------------------------------------------//

			// モード切り替え
			check = 21;									// モード切り替え [送信 -> 受信]

			// 初期化
			num = 0;									// 番号リセット
			for(j = 0; j < 8; j++){

				strcpy(zda[j], "");							// 初期化 [GNZDA]

			}

			// コマンドセット
			strcpy(send, "dm\r\n");								// 停止メッセージ

			// コマンド送信
			err = write(fd, send, strlen(send));						// データ送信

			// コマンドセット
			strcpy(send, "out,");								// 出力設定 [単発]
			strcat(send, serialport);							// シリアルポート設定
			strcat(send, ",/msg/nmea/ZDA:");						// メッセージ
			strcat(send, sendtime);								// 受信速度
			strcat(send, "\r\n");								// 終端コード [<CR><LF>]

			// コマンド送信
			err = write(fd, send, strlen(send));						// データ送信

			// 現在時刻取得
			now_time = gettimeofday_sec();							// 現在時刻取得

			//----------------------------------------------------------------------//


			//-- [データ出力] ------------------------------------------------------//

			m_LegacyDataOut.write();							// データ出力

			//----------------------------------------------------------------------//


			break;										// BREAK

		//------------------------------------------------------------------------------//


		//-- [デフォルト処理] ----------------------------------------------------------//

		default:										// DEFAULT

			break;										// BREAK

		//------------------------------------------------------------------------------//


	}

	//--------------------------------------------------------------------------------------//


	//-- [データ受信] ----------------------------------------------------------------------//

	if(wait_flag == 0){


		//-- [ 現在時刻取得] -----------------------------------------------------------//

		now_time = gettimeofday_sec();								// 現在時刻取得

		//------------------------------------------------------------------------------//


		//-- [メッセージ処理] ----------------------------------------------------------//

		switch(check){


			//-- [GGAメッセージ受信] -----------------------------------------------//

			case 1:										// GGAメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[0] = 1;				// フラグチェック

						}else check_flag[0] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gga_checksum] ");				// label
						printf("gga_message = %s, gga_checksum = %X\n",
							checkbuf, checksum);				// GPGGA
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GPGGAメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'G') && (cbuf[5] == 'A')){	// GGAメッセージ受信 [GPGGA]


							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gga[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gga[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gga[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									gga[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 2;					// モード切り替え [GGA -> GLL]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 2;					// モード切り替え [GGA -> GLL]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GLLメッセージ受信] -----------------------------------------------//

			case 3:										// GLLメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[1] = 1;				// フラグチェック

						}else check_flag[1] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gll_checksum] ");				// label
						printf("gll_message = %s, gll_checksum = %X\n",
							checkbuf, checksum);				// GNGLL
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNGLLメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& ((cbuf[2] == 'N') || (cbuf[2] == 'P') || (cbuf[2] == 'L'))
							&& (cbuf[3] == 'G') && (cbuf[4] == 'L')
							&& (cbuf[5] == 'L')){				// GLLメッセージ受信 [GNGLL]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gll[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gll[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gll[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									gll[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 4;					// モード切り替え [GLL -> GNS]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 4;					// モード切り替え [GLL -> GNS]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GNSメッセージ受信] -----------------------------------------------//

			case 5:										// GNSメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[2] = 1;				// フラグチェック

						}else check_flag[2] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gns_checksum] ");				// label
						printf("gns_message = %s, gns_checksum = %X\n",
							checkbuf, checksum);				// GNGNS
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNGNSメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'N') && (cbuf[5] == 'S')){	// GNSメッセージ受信 [GNGNS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gns[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else{

									gns[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード確認
							if(!((gns[6][0] == 'F' && gns[6][1] == 'F') ||
								(gns[6][0] == 'R' && gns[6][1] == 'R'))){

								// データ初期化 [GPGNS, GLGNS]
								for(j = 0; j < 13; j++){

									strcpy(gp_gns[j], "");		// 初期化 [GPGNS]
									strcpy(gl_gns[j], "");		// 初期化 [GLGNS]

								}

								// モード切り替え
								check = 6;				// モード切り替え [GNS -> GRS]

							}

						//---------------------------------------------//


						//-- [GPGNSメッセージ処理] --------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'N') && (cbuf[5] == 'S')){	// GNSメッセージ受信 [GPGNS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gns[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else{

									gp_gns[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

						//----------------------------------------------//


						//-- [GLGNSメッセージ処理] ---------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'N') && (cbuf[5] == 'S')){	// GNSメッセージ受信 [GLGNS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gns[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else{

									gl_gns[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 6;					// モード切り替え [GNS -> GRS]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 6;					// モード切り替え [GNS -> GRS]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GRSメッセージ受信] -----------------------------------------------//

			case 7:										// GRSメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[3] = 1;				// フラグチェック

						}else check_flag[3] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[grs_checksum] ");				// label
						printf("grs_message = %s, grs_checksum = %X\n",
							checkbuf, checksum);				// GNGRS
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNGRSメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'R') && (cbuf[5] == 'S')
							&& (gp_grs[0][0] == 0x00)){			// GRSメッセージ受信 [GNGRS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gp_grs[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_grs[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'R') && (cbuf[5] == 'S')
							&& (gp_grs[0][0] != 0x00)){			// GRSメッセージ受信 [GNGRS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gl_grs[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_grs[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 8;					// モード切り替え [GRS -> GSA]

						//---------------------------------------------//


						//-- [GPGRSメッセージ処理] --------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'R') && (cbuf[5] == 'S')){	// GRSメッセージ受信 [GPGRS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gp_grs[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_grs[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 8;					// モード切り替え [GRS -> GSA]

						//----------------------------------------------//


						//-- [GLGRSメッセージ処理] ---------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'R') && (cbuf[5] == 'S')){	// GRSメッセージ受信 [GLGRS]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_grs[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gl_grs[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_grs[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 8;					// モード切り替え [GRS -> GSA]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 8;					// モード切り替え [GRS -> GSA]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GSAメッセージ受信] -----------------------------------------------//

			case 9:										// GSAメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[4] = 1;				// フラグチェック

						}else check_flag[4] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gsa_checksum] ");				// label
						printf("gsa_message = %s, gsa_checksum = %X\n",
							checkbuf, checksum);				// GNGSA
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNGSAメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'A')
							&& (gp_gsa[0][0] == 0x00)){			// GSAメッセージ受信 [GNGSA]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gp_gsa[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_gsa[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'A')
							&& (gp_gsa[0][0] != 0x00)){			// GSAメッセージ受信 [GNGSA]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gl_gsa[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_gsa[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 10;					// モード切り替え [GSA -> GST]

						//---------------------------------------------//


						//-- [GPGSAメッセージ処理] --------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'A')){	// GSAメッセージ受信 [GPGSA]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gp_gsa[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_gsa[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 10;					// モード切り替え [GSA -> GST]

						//----------------------------------------------//


						//-- [GLGSAメッセージ処理] ---------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'A')){	// GSAメッセージ受信 [GLGSA]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_gsa[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gl_gsa[mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_gsa[mes_num][count]
										= cbuf[j];		// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 10;					// モード切り替え [GSA -> GST]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 10;					// モード切り替え [GSA -> GST]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GSTメッセージ受信] -----------------------------------------------//

			case 11:									// GSTメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[5] = 1;				// フラグチェック

						}else check_flag[5] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gst_checksum] ");				// label
						printf("gst_message = %s, gst_checksum = %X\n",
							checkbuf, checksum);				// GNGST
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNGSTメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& ((cbuf[2] == 'N') || (cbuf[2] == 'P') || (cbuf[2] == 'L'))
							&& (cbuf[3] == 'G') && (cbuf[4] == 'S')
							&& (cbuf[5] == 'T')){	// GSTメッセージ受信 [GNGST]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gst[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gst[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									gst[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									gst[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 12;					// モード切り替え [GST -> GSV]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 12;					// モード切り替え [GST -> GSV]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [GSVメッセージ受信] -----------------------------------------------//

			case 13:									// GSVメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[6] = 1;				// フラグチェック

						}else check_flag[6] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[gsv_checksum] ");				// label
						printf("gsv_message = %s, gsv_checksum = %X\n",
							checkbuf, checksum);				// GNGSV
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GPGSVメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '1')){				// GSVメッセージ受信 [GPGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gsv[0][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_gsv[0][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gp_gsv[0][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_gsv[0][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '2')){				// GSVメッセージ受信 [GPGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gsv[1][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_gsv[1][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gp_gsv[1][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_gsv[1][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'P') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '3')){				// GSVメッセージ受信 [GPGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gp_gsv[2][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gp_gsv[2][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gp_gsv[2][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gp_gsv[2][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						//---------------------------------------------//


						//-- [GLGSVメッセージ処理] ---------------------//

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '1')){				// GSVメッセージ受信 [GLGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gsv[0][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_gsv[0][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gl_gsv[0][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_gsv[0][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '2')){				// GSVメッセージ受信 [GLGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gsv[1][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_gsv[1][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gl_gsv[1][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_gsv[1][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						}else if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'L') && (cbuf[3] == 'G')
							&& (cbuf[4] == 'S') && (cbuf[5] == 'V')
							&& (cbuf[9] == '3')){				// GSVメッセージ受信 [GLGSV]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									gl_gsv[2][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									gl_gsv[2][mes_num][count]
										= 0x00;			// 終端文字処理
									mes_num = 20;			// メッセージ番号変更
									gl_gsv[2][mes_num][0] = '*';	// データ格納
									count = 1;			// カウンタリセット

								}else{

									gl_gsv[2][mes_num][count]
											= cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

						//---------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 14;					// モード切り替え [GSV -> HDT]

						}

						//----------------------------------------------//


						//-- [後処理] ----------------------------------//

						if((cbuf[2] == 'L') && (cbuf[7] == cbuf[9])){		// GSVメッセージ受信 [GLGSV]

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 14;					// モード切り替え [GSV -> HDT]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [HDTメッセージ受信] -----------------------------------------------//

			case 15:									// HDTメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[7] = 1;				// フラグチェック

						}else check_flag[7] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[hdt_checksum] ");				// label
						printf("hdt_message = %s, hdt_checksum = %X\n",
							checkbuf, checksum);				// GNHDT
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNHDTメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& ((cbuf[2] == 'N') || (cbuf[2] == 'P') || (cbuf[2] == 'L'))
							&& (cbuf[3] == 'H')
							&& (cbuf[4] == 'D') && (cbuf[5] == 'T')){	// HDTメッセージ受信 [GNHDT]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									hdt[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									hdt[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									hdt[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									hdt[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 16;					// モード切り替え [HDT -> RMC]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 16;					// モード切り替え [HDT -> RMC]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [RMCメッセージ受信] -----------------------------------------------//

			case 17:									// RMCメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[8] = 1;				// フラグチェック

						}else check_flag[8] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[rmc_checksum] ");				// label
						printf("rmc_message = %s, rmc_checksum = %X\n",
							checkbuf, checksum);				// GNRMC
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNRMCメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'R')
							&& (cbuf[4] == 'M') && (cbuf[5] == 'C')){	// RMCメッセージ受信 [GNRMC]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									rmc[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									rmc[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									rmc[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									rmc[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 18;					// モード切り替え [RMC -> VTG]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 18;					// モード切り替え [RMC -> VTG]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [VTGメッセージ受信] -----------------------------------------------//

			case 19:									// VTGメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[9] = 1;				// フラグチェック

						}else check_flag[9] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[vtg_checksum] ");				// label
						printf("vtg_message = %s, vtg_checksum = %X\n",
							checkbuf, checksum);				// GNVTG
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNVTGメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& ((cbuf[2] == 'N') || (cbuf[2] == 'P') || (cbuf[2] == 'L'))
							&& (cbuf[3] == 'V')
							&& (cbuf[4] == 'T') && (cbuf[5] == 'G')){	// VTGメッセージ受信 [GNVTG]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									vtg[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									vtg[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号変更
									vtg[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									vtg[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 20;					// モード切り替え [VTG -> ZDA]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 20;					// モード切り替え [VTG -> ZDA]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [ZDAメッセージ受信] -----------------------------------------------//

			case 21:									// ZDAメッセージ受信

				// データ受信
				res = read(fd, buf, BUFSIZE);						// データ受信

				// メッセージ受信
				for(i = 0; i < res; i++){


					//-- [メッセージ受信中] --------------------------------//

					if(buf[i] != 0x0a){						// <LF>チェック

						if(buf[i] != 0x0d){					// <CR>チェック

							cbuf[num] = buf[i];				// データ格納
							num++;						// カウント

						}

					//------------------------------------------------------//


					//-- [メッセージ受信完了] ------------------------------//

					}else{

						// 受信完了処理
						cbuf[num] = 0x00;					// 終端文字処理
						num++;							// カウント
						mes_num = 0;						// メッセージ番号リセット
						count = 0;						// カウントリセット
						checksum = 0;						// チェックサムリセット
						strcpy(checkbuf, "");					// チェックサムバッファリセット

						// チェックサム照合
						for(j = 0; j < num; j++){

							if(cbuf[j] == '$');				// チェックサム開始
							else if(cbuf[j] == '*') break;			// チェックサム終了
							else checksum ^= cbuf[j];			// チェックサム計算

						}

						checkbuf[0] = cbuf[num - 3];				// チェックサム格納
						checkbuf[1] = cbuf[num - 2];				// チェックサム格納
						checkbuf[2] = 0x00;					// 終端文字処理

						if(strtol(checkbuf, NULL, 16) == checksum){

							check_flag[10] = 1;				// フラグチェック

						}else check_flag[10] = 0;				// フラグクリア


						//-- [デバッグCHECKSUM] ------------------------//

						#ifndef DEBUG_CHECKSUM					// デバッグ表示開始

						printf("\n[zda_checksum] ");				// label
						printf("zda_message = %s, zda_checksum = %X\n",
							checkbuf, checksum);				// GNZDA
						fflush(stdout);						// バッファフラッシュ [printf表示用]

						#endif							// デバッグ表示終了

						//----------------------------------------------//


						//-- [GNZDAメッセージ処理] ---------------------//

						if((cbuf[0] == '$') && (cbuf[1] == 'G')
							&& (cbuf[2] == 'N') && (cbuf[3] == 'Z')
							&& (cbuf[4] == 'D') && (cbuf[5] == 'A')){	// ZDAメッセージ受信 [GNZDA]

							// データ格納
							for(j = 0; j < num; j++){

								if(cbuf[j] == ','){			// 区切りチェック

									zda[mes_num][count] = 0x00;	// 終端文字処理
									mes_num++;			// メッセージ番号カウント
									count = 0;			// カウンタリセット

								}else if(cbuf[j] == '*'){		// チェックサムチェック

									zda[mes_num][count] = 0x00;	// 終端文字処理
									mes_num = 7;			// メッセージ番号変更
									zda[mes_num][0] = '*';		// データ格納
									count = 1;			// カウンタリセット

								}else{

									zda[mes_num][count] = cbuf[j];	// データ格納
									count++;			// カウント

								}

							}


							// モード切り替え
							check = 0;					// モード切り替え [VTG -> GGA]

						//----------------------------------------------//


						//-- [例外処理] --------------------------------//

						}else{

							// モード切り替え
							cbuf[0] = 0x00;					// 終端文字処理
							check = 0;					// モード切り替え [ZDA -> GGA]

						}

						//----------------------------------------------//


						num = 0;						// 番号リセット

					}

					//------------------------------------------------------//


				}

				break;									// BREAK

			//----------------------------------------------------------------------//


			//-- [デフォルト処理] --------------------------------------------------//

			default:									// DEFAULT

				break;									// BREAK

			//----------------------------------------------------------------------//


		}

		//------------------------------------------------------------------------------//


		wait_flag = 1;										// フラグリセット

	}

	//--------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

/*
RTC::ReturnCode_t GpsService::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t GpsService::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{

  void GpsServiceInit(RTC::Manager* manager)
  {
    RTC::Properties profile(gpsservice_spec);
    manager->registerFactory(profile,
                             RTC::Create<GpsService>,
                             RTC::Delete<GpsService>);
  }

};


